EXPORTS
	?CreateTestSuiteL@@YAPAVMEUnitTest@@XZ @ 1 NONAME ; class MEUnitTest * CreateTestSuiteL(void)
	??1CSTUNClient@@UAE@XZ @ 2 NONAME ; CSTUNClient::~CSTUNClient(void)
	??1CSTUNRelayBinding@@UAE@XZ @ 3 NONAME ; CSTUNRelayBinding::~CSTUNRelayBinding(void)
	?AddressResolved@CSTUNRelayBinding@@UBEHXZ @ 4 NONAME ; int CSTUNRelayBinding::AddressResolved(void) const
	?AllocateRequestL@CSTUNRelayBinding@@QAEXI@Z @ 5 NONAME ; void CSTUNRelayBinding::AllocateRequestL(unsigned int)
	?AlternateServerAddr@CSTUNRelayBinding@@UBEABVTInetAddr@@XZ @ 6 NONAME ; class TInetAddr const & CSTUNRelayBinding::AlternateServerAddr(void) const
	?CancelMessageSend@CNcmConnectionMultiplexer@@UAEXIIPBVMNcmSenderObserver@@@Z @ 7 NONAME ; void CNcmConnectionMultiplexer::CancelMessageSend(unsigned int, unsigned int, class MNcmSenderObserver const *)
	?CancelRequest@CSTUNRelayBinding@@UAEXXZ @ 8 NONAME ; void CSTUNRelayBinding::CancelRequest(void)
	?CloseTcpConnection@CNcmConnectionMultiplexer@@UAEXII@Z @ 9 NONAME ; void CNcmConnectionMultiplexer::CloseTcpConnection(unsigned int, unsigned int)
	?ConnectRequestL@CSTUNRelayBinding@@QAEXABVTInetAddr@@@Z @ 10 NONAME ; void CSTUNRelayBinding::ConnectRequestL(class TInetAddr const &)
	?ConnectionId@CSTUNRelayBinding@@UBEIXZ @ 11 NONAME ; unsigned int CSTUNRelayBinding::ConnectionId(void) const
	?CreateConnectionL@CNcmConnectionMultiplexer@@UAEIIABVTInetAddr@@@Z @ 12 NONAME ; unsigned int CNcmConnectionMultiplexer::CreateConnectionL(unsigned int, class TInetAddr const &)
	?CreateConnectionL@CNcmConnectionMultiplexer@@UAEIII@Z @ 13 NONAME ; unsigned int CNcmConnectionMultiplexer::CreateConnectionL(unsigned int, unsigned int)
	?CreateSessionL@CNcmConnectionMultiplexer@@QAEIKII@Z @ 14 NONAME ; unsigned int CNcmConnectionMultiplexer::CreateSessionL(unsigned long, unsigned int, unsigned int)
	?CreateStreamL@CNcmConnectionMultiplexer@@QAEIIHI@Z @ 15 NONAME ; unsigned int CNcmConnectionMultiplexer::CreateStreamL(unsigned int, int, unsigned int)
	?GetSessionInfoL@CNcmConnectionMultiplexer@@QAEPAVRSocketServ@@IAAV?$TBuf@$0IA@@@@Z @ 16 NONAME ; class RSocketServ * CNcmConnectionMultiplexer::GetSessionInfoL(unsigned int, class TBuf<128> &)
	?GetStreamInfoL@CNcmConnectionMultiplexer@@UAEXIAAKAAHAAI@Z @ 17 NONAME ; void CNcmConnectionMultiplexer::GetStreamInfoL(unsigned int, unsigned long &, int &, unsigned int &)
	?HandleDataL@CSTUNRelayBinding@@UAEPAVHBufC8@@ABVTDesC8@@AAHAAVTInetAddr@@@Z @ 18 NONAME ; class HBufC8 * CSTUNRelayBinding::HandleDataL(class TDesC8 const &, int &, class TInetAddr &)
	?IsInitialized@CSTUNClient@@QBEHXZ @ 19 NONAME ; int CSTUNClient::IsInitialized(void) const
	?LocalIPAddressL@CNcmConnectionMultiplexer@@UAEAAVTInetAddr@@II@Z @ 20 NONAME ; class TInetAddr & CNcmConnectionMultiplexer::LocalIPAddressL(unsigned int, unsigned int)
	?NewL@CNcmConnectionMultiplexer@@SAPAV1@AAVMNcmConnectionMultiplexerObserver@@@Z @ 21 NONAME ; class CNcmConnectionMultiplexer * CNcmConnectionMultiplexer::NewL(class MNcmConnectionMultiplexerObserver &)
	?NewL@CSTUNClient@@SAPAV1@HAAVCDeltaTimer@@AAVMSTUNClientObserver@@PAVMNcmConnectionMultiplexer@@W4TTransportProtocol@@@Z @ 22 NONAME ; class CSTUNClient * CSTUNClient::NewL(int, class CDeltaTimer &, class MSTUNClientObserver &, class MNcmConnectionMultiplexer *, enum TTransportProtocol)
	?NewL@CSTUNClient@@SAPAV1@HABVTDesC8@@I0AAVRSocketServ@@AAVRConnection@@AAVCDeltaTimer@@AAVMSTUNClientObserver@@HHHPAVMNcmConnectionMultiplexer@@W4TTransportProtocol@@@Z @ 23 NONAME ; class CSTUNClient * CSTUNClient::NewL(int, class TDesC8 const &, unsigned int, class TDesC8 const &, class RSocketServ &, class RConnection &, class CDeltaTimer &, class MSTUNClientObserver &, int, int, int, class MNcmConnectionMultiplexer *, enum TTransportProtocol)
	?NewL@CSTUNRelayBinding@@SAPAV1@AAVCSTUNClient@@II@Z @ 24 NONAME ; class CSTUNRelayBinding * CSTUNRelayBinding::NewL(class CSTUNClient &, unsigned int, unsigned int)
	?NewLC@CSTUNClient@@SAPAV1@HAAVCDeltaTimer@@AAVMSTUNClientObserver@@PAVMNcmConnectionMultiplexer@@W4TTransportProtocol@@@Z @ 25 NONAME ; class CSTUNClient * CSTUNClient::NewLC(int, class CDeltaTimer &, class MSTUNClientObserver &, class MNcmConnectionMultiplexer *, enum TTransportProtocol)
	?NewLC@CSTUNClient@@SAPAV1@HABVTDesC8@@I0AAVRSocketServ@@AAVRConnection@@AAVCDeltaTimer@@AAVMSTUNClientObserver@@HHHPAVMNcmConnectionMultiplexer@@W4TTransportProtocol@@@Z @ 26 NONAME ; class CSTUNClient * CSTUNClient::NewLC(int, class TDesC8 const &, unsigned int, class TDesC8 const &, class RSocketServ &, class RConnection &, class CDeltaTimer &, class MSTUNClientObserver &, int, int, int, class MNcmConnectionMultiplexer *, enum TTransportProtocol)
	?NewLC@CSTUNRelayBinding@@SAPAV1@AAVCSTUNClient@@II@Z @ 27 NONAME ; class CSTUNRelayBinding * CSTUNRelayBinding::NewLC(class CSTUNClient &, unsigned int, unsigned int)
	?ObtainTransactionIDL@CSTUNClient@@QAEXAAVTDesC8@@@Z @ 28 NONAME ; void CSTUNClient::ObtainTransactionIDL(class TDesC8 &)
	?OpenTcpConnectionL@CNcmConnectionMultiplexer@@UAEXIIW4TNATFWTcpConnectionSetup@@ABVTInetAddr@@@Z @ 29 NONAME ; void CNcmConnectionMultiplexer::OpenTcpConnectionL(unsigned int, unsigned int, enum TNATFWTcpConnectionSetup, class TInetAddr const &)
	?PortStoreL@CNcmConnectionMultiplexer@@QAEAAVCNcmPortStore@@I@Z @ 30 NONAME ; class CNcmPortStore & CNcmConnectionMultiplexer::PortStoreL(unsigned int)
	?PublicAddr@CSTUNRelayBinding@@UBEABVTInetAddr@@XZ @ 31 NONAME ; class TInetAddr const & CSTUNRelayBinding::PublicAddr(void) const
	?RealmFromResponse@CSTUNRelayBinding@@UBEPBVHBufC8@@XZ @ 32 NONAME ; class HBufC8 const * CSTUNRelayBinding::RealmFromResponse(void) const
	?RegisterConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmConnectionObserver@@@Z @ 33 NONAME ; void CNcmConnectionMultiplexer::RegisterConnectionObserverL(unsigned int, class MNcmConnectionObserver &)
	?RegisterIncomingConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmIncomingConnectionObserver@@@Z @ 34 NONAME ; void CNcmConnectionMultiplexer::RegisterIncomingConnectionObserverL(unsigned int, class MNcmIncomingConnectionObserver &)
	?RegisterMediaWrapperL@CNcmConnectionMultiplexer@@QAEXPAVMNATFWMediaWrapper@@@Z @ 35 NONAME ; void CNcmConnectionMultiplexer::RegisterMediaWrapperL(class MNATFWMediaWrapper *)
	?RegisterMessageObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmMessageObserver@@@Z @ 36 NONAME ; void CNcmConnectionMultiplexer::RegisterMessageObserverL(unsigned int, class MNcmMessageObserver &)
	?RegisterOutgoingConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmOutgoingConnectionObserver@@@Z @ 37 NONAME ; void CNcmConnectionMultiplexer::RegisterOutgoingConnectionObserverL(unsigned int, class MNcmOutgoingConnectionObserver &)
	?RelayAddr@CSTUNRelayBinding@@QBEABVTInetAddr@@XZ @ 38 NONAME ; class TInetAddr const & CSTUNRelayBinding::RelayAddr(void) const
	?RemoveConnectionL@CNcmConnectionMultiplexer@@UAEXII@Z @ 39 NONAME ; void CNcmConnectionMultiplexer::RemoveConnectionL(unsigned int, unsigned int)
	?RemoveSessionL@CNcmConnectionMultiplexer@@QAEXI@Z @ 40 NONAME ; void CNcmConnectionMultiplexer::RemoveSessionL(unsigned int)
	?RemoveStreamL@CNcmConnectionMultiplexer@@QAEXI@Z @ 41 NONAME ; void CNcmConnectionMultiplexer::RemoveStreamL(unsigned int)
	?STUNClient@CSTUNRelayBinding@@UBEPBVCSTUNClient@@XZ @ 42 NONAME ; class CSTUNClient const * CSTUNRelayBinding::STUNClient(void) const
	?STUNServerAddrL@CSTUNClient@@QBEABVTInetAddr@@XZ @ 43 NONAME ; class TInetAddr const & CSTUNClient::STUNServerAddrL(void) const
	?SendIndicationL@CSTUNRelayBinding@@UAEXABVTInetAddr@@ABVTDesC8@@H@Z @ 44 NONAME ; void CSTUNRelayBinding::SendIndicationL(class TInetAddr const &, class TDesC8 const &, int)
	?SendL@CNcmConnectionMultiplexer@@UAEXIABVTDesC8@@ABVTInetAddr@@1@Z @ 45 NONAME ; void CNcmConnectionMultiplexer::SendL(unsigned int, class TDesC8 const &, class TInetAddr const &, class TInetAddr const &)
	?SendL@CNcmConnectionMultiplexer@@UAEXIIABVTDesC8@@ABVTInetAddr@@PAVMNcmSenderObserver@@@Z @ 46 NONAME ; void CNcmConnectionMultiplexer::SendL(unsigned int, unsigned int, class TDesC8 const &, class TInetAddr const &, class MNcmSenderObserver *)
	?SendL@CNcmConnectionMultiplexer@@UAEXIIABVTDesC8@@HPAVMNcmSenderObserver@@@Z @ 47 NONAME ; void CNcmConnectionMultiplexer::SendL(unsigned int, unsigned int, class TDesC8 const &, int, class MNcmSenderObserver *)
	?SendL@CNcmConnectionMultiplexer@@UAEXIIABVTDesC8@@PAVMNcmSenderObserver@@@Z @ 48 NONAME ; void CNcmConnectionMultiplexer::SendL(unsigned int, unsigned int, class TDesC8 const &, class MNcmSenderObserver *)
	?SetAcceptedFromAddressL@CNcmConnectionMultiplexer@@UAEXIIABVTInetAddr@@@Z @ 49 NONAME ; void CNcmConnectionMultiplexer::SetAcceptedFromAddressL(unsigned int, unsigned int, class TInetAddr const &)
	?SetActiveDestinationRequestL@CSTUNRelayBinding@@QAEXABVTInetAddr@@AAK@Z @ 50 NONAME ; void CSTUNRelayBinding::SetActiveDestinationRequestL(class TInetAddr const &, unsigned long &)
	?SetCredentialsL@CSTUNClient@@QAEXABVTDesC8@@0@Z @ 51 NONAME ; void CSTUNClient::SetCredentialsL(class TDesC8 const &, class TDesC8 const &)
	?SetICESpecificAttributes@CSTUNRelayBinding@@UAEXABVTICEAttributes@@@Z @ 52 NONAME ; void CSTUNRelayBinding::SetICESpecificAttributes(class TICEAttributes const &)
	?SetReceivingStateL@CNcmConnectionMultiplexer@@UAEXIIW4TNATFWStreamingState@@@Z @ 53 NONAME ; void CNcmConnectionMultiplexer::SetReceivingStateL(unsigned int, unsigned int, enum TNATFWStreamingState)
	?SetSendingStateL@CNcmConnectionMultiplexer@@UAEXIIABVTInetAddr@@W4TNATFWStreamingState@@@Z @ 54 NONAME ; void CNcmConnectionMultiplexer::SetSendingStateL(unsigned int, unsigned int, class TInetAddr const &, enum TNATFWStreamingState)
	?SharedSecretObtained@CSTUNClient@@QBEHXZ @ 55 NONAME ; int CSTUNClient::SharedSecretObtained(void) const
	?StreamId@CSTUNRelayBinding@@UBEIXZ @ 56 NONAME ; unsigned int CSTUNRelayBinding::StreamId(void) const
	?UnregisterConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmConnectionObserver@@@Z @ 57 NONAME ; void CNcmConnectionMultiplexer::UnregisterConnectionObserverL(unsigned int, class MNcmConnectionObserver &)
	?UnregisterIncomingConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmIncomingConnectionObserver@@@Z @ 58 NONAME ; void CNcmConnectionMultiplexer::UnregisterIncomingConnectionObserverL(unsigned int, class MNcmIncomingConnectionObserver &)
	?UnregisterMessageObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmMessageObserver@@@Z @ 59 NONAME ; void CNcmConnectionMultiplexer::UnregisterMessageObserverL(unsigned int, class MNcmMessageObserver &)
	?UnregisterOutgoingConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmOutgoingConnectionObserver@@@Z @ 60 NONAME ; void CNcmConnectionMultiplexer::UnregisterOutgoingConnectionObserverL(unsigned int, class MNcmOutgoingConnectionObserver &)

